@@ -529,7 +529,7 @@ class _TimeDate:
             (Time): Temps restant
         """
         return Time(
-            self.year - other.year, self.month - other.month, self.day - other.day + 1,
+            self.year - other.year, self.month - other.month, self.day - other.day,
             self.hour - other.hour, self.minute - other.minute, self.second - other.second,
             self.milli - other.milli, self.micro - other.micro, self.nano - other.nano,
             self.pico - other.pico, self.femto - other.femto, self.atto - other.atto,
